/*
 * DemosceneMusic - Artist.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.data;

import java.util.Collection;
import java.util.Comparator;

/**
 * Default implementation for an artist data container.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class DefaultArtist extends DefaultBase implements Artist {

	/** Comparator that sorts artists by name. */
	public static final Comparator<Artist> NAME_COMPARATOR = new Comparator<Artist>() {

		@Override
		public int compare(Artist leftArtist, Artist rightArtist) {
			return leftArtist.getName().compareToIgnoreCase(rightArtist.getName());
		}
	};

	/**
	 * Creates a new artist data container.
	 *
	 * @param id
	 *            The ID of the artist
	 */
	public DefaultArtist(String id) {
		super(id);
	}

	//
	// ARTIST METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return getValue("name", String.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Artist setName(String name) {
		getValue("name", String.class).set(name);
		return this;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	@SuppressWarnings("unchecked")
	public Collection<Group> getGroups() {
		return getValue("groups", Collection.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Artist setGroups(Collection<Group> groups) {
		getValue("groups", Collection.class).set(groups);
		return this;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	@SuppressWarnings({ "unchecked" })
	public Collection<Track> getTracks() {
		return getValue("tracks", Collection.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Artist setTracks(Collection<Track> tracks) {
		getValue("tracks", Collection.class).set(tracks);
		return this;
	}

	//
	// OBJECT METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int hashCode() {
		return getId().hashCode();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean equals(Object object) {
		if (!(object instanceof Artist)) {
			return false;
		}
		return ((Artist) object).getId().equals(getId());
	}

}
