/*
 * DemosceneMusic - EditDerivativePage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page.admin;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.demoscenemusic.data.Track;
import net.pterodactylus.demoscenemusic.data.TrackDerivative;
import net.pterodactylus.demoscenemusic.page.ServletRequest;
import net.pterodactylus.util.database.DatabaseException;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContext;
import net.pterodactylus.util.template.TemplateContextFactory;
import net.pterodactylus.util.web.Method;
import net.pterodactylus.util.web.RedirectException;

/**
 * Page that lets a user edit a derivative.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class EditDerivativePage extends AdminBasePage {

	/**
	 * Creates a new edit-derivative page.
	 *
	 * @param core
	 *            The core
	 * @param templateContextFactory
	 *            The template context factory
	 * @param template
	 *            The template to render
	 */
	public EditDerivativePage(Core core, TemplateContextFactory templateContextFactory, Template template) {
		super(core, templateContextFactory, template, "admin.edit-derivative");
	}

	//
	// BASEPAGE METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void processTemplate(TemplateContext templateContext, ServletRequest request) throws RedirectException {
		super.processTemplate(templateContext, request);
		if (request.getMethod() == Method.POST) {

			try {

				String trackId = request.getServletRequest().getParameter("track");
				Track track = getCore().getDataManager().getTrackById(trackId);
				String derivativeId = request.getServletRequest().getParameter("derivative");
				TrackDerivative derivative = getCore().getDataManager().getTrackDerivativeById(derivativeId);

				if ("true".equals(request.getServletRequest().getParameter("delete"))) {
					getCore().getDataDirectory().removeFile(derivativeId);
					getCore().getDataManager().removeTrackDerivative(derivative);
					throw new RedirectException("admin.edit-track?id=" + track.getId());
				}

				processProperties(request, derivative);
				getCore().getDataManager().saveTrackDerivate(derivative);
				throw new RedirectException("admin.edit-track?id=" + track.getId());

			} catch (DatabaseException de1) {
				throw new RuntimeException("Could not edit derivative.", de1);
			}
		}
	}

}
